ILog = IObject.subClass();

ILog.ERROR = 3;
ILog.INFO = 2;
ILog.DEBUG = 1;

ILog.PANEL = 0;
ILog.HTTP = 1;

ILog.NAME = "log:panel";

ILog.level = ILog.INFO;

ILog.error = function(string, object){
	if(ILog.level <= ILog.ERROR)
		this.write(this.formatMessage(string, object, ILog.ERROR));
}

ILog.info = function(string, object){
	if(ILog.level <= ILog.INFO)
		this.write(this.formatMessage(string, object, ILog.INFO));
}

ILog.debug = function(string, object){
	if(ILog.level <= ILog.DEBUG)
		this.write(this.formatMessage(string, object, ILog.DEBUG));
}

ILog.alert = function(string, object){
	if(object)
		window.alert(object.URL + string);
	else
		window.alert(string);
}

ILog.write = function(message){
	if(this.enabled){
		if(this.method == ILog.PANEL)
			this.panelLog(message);
		else
			this.httpLog(message);
	}
}

ILog.method = ILog.PANEL;

ILog.enabled = false;

ILog.init = function(){
	var panel = ICanvas.getPanel(ILog.NAME);
	if(panel)
		document.body.appendChild(panel);
	else{
		panel = ICanvas.createPanel(ILog.NAME, 400, 320, 10, document.body.clientWidth - 420);
		panel.firstChild.innerHTML = "ILog levels : <a href=\"javascript:ILog.filter('log:error');\"><font color=\"#cc3300\">error</font></a>";
		panel.firstChild.innerHTML += " | <a href=\"javascript:ILog.filter('log:info');\"><font color=\"#3366ff\">info</font></a>";
		panel.firstChild.innerHTML += " | <a href=\"javascript:ILog.filter('log:debug');\"><font color=\"#339900\">debug</font></a>";
		panel.firstChild.innerHTML += " | <a href=\"javascript:ILog.filter('log:all');\"><font color=\"#000000\">all</font></a>";
		panel.lastChild.style.height = panel.offsetHeight - panel.firstChild.offsetHeight;
		if(navigator.userAgent.indexOf("Gecko")>=0)
			panel.lastChild.style.height = parseFloat(panel.lastChild.style.height) - 12;
		panel.lastChild.style.padding = "5";
		panel.lastChild.style.overflow = "auto";
		window.onscroll = this.onScroll;
		window.onresize = this.onResize;
	}
	return panel;
}

ILog.panelLog = function(message){
	var panel = ICanvas.getPanel(ILog.NAME);
	if(!panel){
		panel = this.init();
	}
	panel.lastChild.innerHTML = message + panel.lastChild.innerHTML;
}

ILog.httpLog = function(message){
	
}


ILog.formatMessage = function (msg, obj, level){
	var prefix = "[" + new Date().toLocaleString() + "] ";
	if(obj)
		prefix += "[" + obj + "] ";
	var message = "";
	switch(level){
		case ILog.ERROR : message += "<div name=\"log:error\">" + prefix + "[ERROR] <font color=\"#cc3300\">";break;
		case ILog.INFO : message += "<div name=\"log:info\">" + prefix + "[INFO] <font color=\"#3366ff\">";break;
		case ILog.DEBUG : message += "<div name=\"log:debug\">" + prefix + "[DEBUG] <font color=\"#339900\">";break;
		default : message += "<div name=\"log:default\">" + prefix + "[DEFAULT] <font color=\"000000\">";break;
	}
	message += msg;
	message += "</font></div>";
	return message;
}

ILog.switchLog = function(){
	var panel = ICanvas.getPanel(ILog.NAME);
	if(panel && panel.parentNode && panel.parentNode.nodeName.toLowerCase() == "body"){
		this.remove();
		this.debug("state : off", "ILog.js");
		//this.clear();
		this.enabled = false;
	}else{
		this.init();
		this.enabled = true;
		this.debug("state : on", "ILog.js");
	}
}

ILog.clear = function () {
	var panel = ICanvas.getPanel(ILog.NAME);
	panel.lastChild.innerHTML = "";
}

ILog.remove = function (){
	ICanvas.removePanel(ILog.NAME);
}

ILog.onScroll = function(){
	var panel = ICanvas.getPanel(ILog.NAME);
	if(panel)
		panel.style.top = document.body.scrollTop + 10;
};

ILog.onResize = function(){
	var panel = ICanvas.getPanel(ILog.NAME);
	if(panel && document.body.clientWidth > 420)
		panel.style.left = document.body.clientWidth - 420;
	else if(panel && document.body.clientWidth < 420)
		panel.style.left = 10;
};

ILog.hidden = function(){
	var panel = ICanvas.getPanel(ILog.NAME);
	if(panel)
		panel.style.display = "hidden";
}

ILog.show = function(){
	var panel = ICanvas.getPanel(ILog.NAME);
	if(panel)
		panel.style.display = "block";
}

ILog.filter = function(name){
	var panel = ICanvas.getPanel(ILog.NAME);
	var els = panel.lastChild.getElementsByTagName("div");
	for(var i = 0; i < els.length; i ++){
		if(name == "log:all"){
			els[i].style.display = "block";
		}else{
			if(els[i].getAttribute("name") == name){
				els[i].style.display = "block";
			}else{
				els[i].style.display = "none";
			}
		}
	}
}